'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _request = require('request');

var _request2 = _interopRequireDefault(_request);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _url = require('url');

var _url2 = _interopRequireDefault(_url);

var _util = require('util');

var _util2 = _interopRequireDefault(_util);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var get = function get(filePath) {
  return new Promise(function (resolve, reject) {
    _fs2.default.readFile(filePath, function (err, buf) {
      if (err) reject(err);else resolve(buf.toString());
    });
  });
};

var log = function log(title, obj) {
  console.log('\n-------------------------\n' + title + '\n-------------------------');
  console.log(_util2.default.inspect(obj, {
    depth: 4,
    colors: true
  }));
};

var parseResponse = function parseResponse(res, isDownload) {
  return {
    status: res.statusCode,
    statusText: res.statusMessage,
    headers: res.headers,
    body: isDownload ? '' : res.body.toString()
  };
};

/**
 * config properties:
 * url - string - url to call
 * method - string - http method
 * query - object - query hash
 * headers - object - headers hash
 * body - string - body to send
 * importFile - string - file path for upload
 * exportFile - string - file path for download
 * upload - string - name of the form field for upload
 */
var request = function request(config, logg) {
  return new Promise(function (resolve, reject) {
    var options = {
      uri: config.url,
      method: config.method,
      headers: config.headers,
      body: config.body,
      qs: config.query
    };

    if (config.importFile) {
      logg('Request Configuration', Object.assign({}, options, { formData: config.importFile }));
      options.formData = {};
      options.formData[config.formField] = _fs2.default.createReadStream(config.importFile);
    } else {
      logg('Request Configuration', options);
    }

    var req = (0, _request2.default)(options, function (err, res) {
      if (err) reject(err);else {
        resolve(parseResponse(res, config.exportFile !== undefined));
      }
    });
    if (config.exportFile) req.pipe(_fs2.default.createWriteStream(config.exportFile));
  });
};

var urlParse = function urlParse(urlString) {
  return _url2.default.parse(urlString, true);
};

var btoa = function btoa(str) {
  return new Buffer(str, 'utf8').toString('base64');
};

exports.default = {
  get: get,
  request: request,
  urlParse: urlParse,
  log: log,
  btoa: btoa
};
//# sourceMappingURL=index.js.map